/*
  a metaPlayer stores a device tree and can change internally the yafPlayer
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */




#ifndef __METAPLAYER_H
#define __METAPLAYER_H



#include <util/controlChannel.h>
#include <devices/genericStreamProducer.h>
#include <iostream.h>





/** 
   The MetaPlayer class is the class from which a GUI should
   derive from. You can see the MetaPlayer as an "empty"
   hifi-player. It has buttons for open,close,... and
   it constructs the internally devices like timeDisplay
   and the spectrumAnalyser (or more) and stores these devices
   forever. But what is missing in this class ist the
   "mechanik parts" which make the musik. This is done
   by a yaf-player who does not now about the
   devices in the MetaPlayer. You can attach a yafPlayer
   to a MetaPlayer. The MetaPlayer then connect its
   device tree to the player and waits for input (like play).
   <p>
   Then on another command (the User selects the next item
   out of the playlist) The MetaPlayer stays on the screen,
   But this time we need a player which does not decode
   mp3 files but midi. Thus we remove the yafPlayer
   from the MetaPlayer and insert a yafPlayer who
   knows hot to play midi files. 
   But this may not be the only reason to remove the yafPlayer
   from the MetaPlayer. Another may be that you have already
   pre-decoded a mp3 file in a seperate yafPlayer. And for
   optimizing reasons you do not send the current player
   a new open(xxx) but remove it and insert a well filled
   yafPlayer.
   <p>
   In general the MetaPlayer has the task to store the devices,
   because these stay the same or can be removed, switched on/off,
   or the user can add new device (like a device which writes
   the pcm data to a wav file). This device tree is in the MetaPlayer,
   or better said in a derived class. Because the MetaPlayer is an
   abstract class.


*/



class MetaPlayer  {

  GenericStreamProducer* streamProducer;


 public:
  MetaPlayer();
  virtual ~MetaPlayer();

  virtual int open(char* filename );
  int close();
  int pause();
  int play();
  int jump(int sec);

  virtual void setGenericStreamProducer(GenericStreamProducer* producer);
  GenericStreamProducer* getGenericStreamProducer();


 protected:
  virtual OutputDevice* getInternalDeviceTree();
  

};

#endif




   
